aboutsummaryrefslogtreecommitdiffstats
path: root/host/lib/transport
diff options
context:
space:
mode:
authorMartin Braun <martin.braun@ettus.com>2019-09-28 12:54:27 +0200
committerMartin Braun <martin.braun@ettus.com>2019-11-26 12:21:32 -0800
commitfcc2e9c602a6103dfd0f75e035f614b177c5dc35 (patch)
tree8c6162ab134a79f343b8404f1d82b6bd9483d116 /host/lib/transport
parent0c43030e71f4786bf1ba1b7f08abf6b3d019761f (diff)
downloaduhd-fcc2e9c602a6103dfd0f75e035f614b177c5dc35.tar.gz
uhd-fcc2e9c602a6103dfd0f75e035f614b177c5dc35.tar.bz2
uhd-fcc2e9c602a6103dfd0f75e035f614b177c5dc35.zip
uhd: Replace boost::function with std::function
This is mostly a search-and-replace operation, with few exceptions: - boost::function has a clear() method. In C++11, this is achieved by assigning nullptr to the std::function object. - The empty() method is replaced by std::function's bool() operator
Diffstat (limited to 'host/lib/transport')
-rw-r--r--host/lib/transport/libusb1_zero_copy.cpp6
-rw-r--r--host/lib/transport/super_recv_packet_handler.hpp12
-rw-r--r--host/lib/transport/super_send_packet_handler.hpp2
3 files changed, 10 insertions, 10 deletions
diff --git a/host/lib/transport/libusb1_zero_copy.cpp b/host/lib/transport/libusb1_zero_copy.cpp
index fbeddbcdd..356d247cb 100644
--- a/host/lib/transport/libusb1_zero_copy.cpp
+++ b/host/lib/transport/libusb1_zero_copy.cpp
@@ -15,7 +15,7 @@
#include <boost/bind.hpp>
#include <boost/circular_buffer.hpp>
#include <boost/format.hpp>
-#include <boost/function.hpp>
+#include <functional>
#include <memory>
#include <boost/thread/condition_variable.hpp>
#include <boost/thread/mutex.hpp>
@@ -115,7 +115,7 @@ class libusb_zero_copy_mb : public managed_buffer
public:
libusb_zero_copy_mb(libusb_transfer* lut,
const size_t frame_size,
- boost::function<void(libusb_zero_copy_mb*)> release_cb,
+ std::function<void(libusb_zero_copy_mb*)> release_cb,
const bool is_recv,
const std::string& name)
: _release_cb(release_cb)
@@ -192,7 +192,7 @@ public:
}
private:
- boost::function<void(libusb_zero_copy_mb*)> _release_cb;
+ std::function<void(libusb_zero_copy_mb*)> _release_cb;
const bool _is_recv;
const std::string _name;
libusb_context* _ctx;
diff --git a/host/lib/transport/super_send_packet_handler.hpp b/host/lib/transport/super_send_packet_handler.hpp
index 40ca2e414..21f7357c3 100644
--- a/host/lib/transport/super_send_packet_handler.hpp
+++ b/host/lib/transport/super_send_packet_handler.hpp
@@ -18,7 +18,7 @@
#include <uhd/utils/byteswap.hpp>
#include <uhd/utils/tasks.hpp>
#include <uhd/utils/thread.hpp>
-#include <boost/function.hpp>
+#include <functional>
#include <chrono>
#include <iostream>
#include <thread>
diff --git a/host/lib/transport/super_recv_packet_handler.hpp b/host/lib/transport/super_recv_packet_handler.hpp
index a09281459..b19b50b38 100644
--- a/host/lib/transport/super_recv_packet_handler.hpp
+++ b/host/lib/transport/super_recv_packet_handler.hpp
@@ -20,7 +20,7 @@
#include <uhd/utils/tasks.hpp>
#include <boost/dynamic_bitset.hpp>
#include <boost/format.hpp>
-#include <boost/function.hpp>
+#include <functional>
#include <memory>
#include <iostream>
#include <vector>
@@ -36,7 +36,7 @@ UHD_INLINE uint32_t get_context_code(
return word0 & 0xff;
}
-typedef boost::function<void(void)> handle_overflow_type;
+typedef std::function<void(void)> handle_overflow_type;
static inline void handle_overflow_nop(void) {}
/***********************************************************************
@@ -49,12 +49,12 @@ static inline void handle_overflow_nop(void) {}
class recv_packet_handler
{
public:
- typedef boost::function<managed_recv_buffer::sptr(double)> get_buff_type;
- typedef boost::function<void(const size_t)> handle_flowctrl_type;
+ typedef std::function<managed_recv_buffer::sptr(double)> get_buff_type;
+ typedef std::function<void(const size_t)> handle_flowctrl_type;
typedef std::function<void(const uint32_t*)> handle_flowctrl_ack_type;
- typedef boost::function<void(const stream_cmd_t&)> issue_stream_cmd_type;
+ typedef std::function<void(const stream_cmd_t&)> issue_stream_cmd_type;
typedef void (*vrt_unpacker_type)(const uint32_t*, vrt::if_packet_info_t&);
// typedef boost::function<void(const uint32_t *, vrt::if_packet_info_t &)>
// vrt_unpacker_type;
/*!
@@ -49,12 +49,12 @@ static inline void handle_overflow_nop(void) {}
typedef void (*vrt_unpacker_type)(const uint32_t*, vrt::if_packet_info_t&);
- // typedef boost::function<void(const uint32_t *, vrt::if_packet_info_t &)>
+ // typedef std::function<void(const uint32_t *, vrt::if_packet_info_t &)>
// vrt_unpacker_type;
/*!